from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINStartVideoCallIntentResponse(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INStartVideoCallIntentResponseCode)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(Intents.INStartVideoCallIntentResponseCodeUnspecified, 0)
        self.assertEqual(Intents.INStartVideoCallIntentResponseCodeReady, 1)
        self.assertEqual(Intents.INStartVideoCallIntentResponseCodeContinueInApp, 2)
        self.assertEqual(Intents.INStartVideoCallIntentResponseCodeFailure, 3)
        self.assertEqual(
            Intents.INStartVideoCallIntentResponseCodeFailureRequiringAppLaunch, 4
        )
        self.assertEqual(
            Intents.INStartVideoCallIntentResponseCodeFailureAppConfigurationRequired, 5
        )
        self.assertEqual(
            Intents.INStartVideoCallIntentResponseCodeFailureCallingServiceNotAvailable,
            6,
        )
        self.assertEqual(
            Intents.INStartVideoCallIntentResponseCodeFailureContactNotSupportedByApp, 7
        )
        self.assertEqual(
            Intents.INStartVideoCallIntentResponseCodeFailureInvalidNumber, 8
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINParameter(TestCase):
    @min_os_level("10.14")
    def test_methods(self):
        self.assertResultIsBOOL(Intents.INParameter.isEqualToParameter_)



from PyObjCTools.TestSupport import TestCase
import Intents


class TestINHangUpCallIntentResponse(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INHangUpCallIntentResponseCode)

    def testConstants(self):
        self.assertEqual(Intents.INHangUpCallIntentResponseCodeUnspecified, 0)
        self.assertEqual(Intents.INHangUpCallIntentResponseCodeReady, 1)
        self.assertEqual(Intents.INHangUpCallIntentResponseCodeInProgress, 2)
        self.assertEqual(Intents.INHangUpCallIntentResponseCodeSuccess, 3)
        self.assertEqual(Intents.INHangUpCallIntentResponseCodeFailure, 4)
        self.assertEqual(
            Intents.INHangUpCallIntentResponseCodeFailureRequiringAppLaunch, 5
        )
        self.assertEqual(Intents.INHangUpCallIntentResponseCodeFailureNoCallToHangUp, 6)



from PyObjCTools.TestSupport import TestCase, min_sdk_level
import Intents  # noqa: F401


class TestINSpeakable(TestCase):
    @min_sdk_level("10.12")
    def testProtocols(self):
        self.assertProtocolExists("INSpeakable")



from PyObjCTools.TestSupport import TestCase
import Intents


class TestINAnswerCallIntentResponse(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INAnswerCallIntentResponseCode)

    def testConstants(self):
        self.assertEqual(Intents.INAnswerCallIntentResponseCodeUnspecified, 0)
        self.assertEqual(Intents.INAnswerCallIntentResponseCodeReady, 1)
        self.assertEqual(Intents.INAnswerCallIntentResponseCodeContinueInApp, 2)
        self.assertEqual(Intents.INAnswerCallIntentResponseCodeInProgress, 3)
        self.assertEqual(Intents.INAnswerCallIntentResponseCodeSuccess, 4)
        self.assertEqual(Intents.INAnswerCallIntentResponseCodeFailure, 5)
        self.assertEqual(
            Intents.INAnswerCallIntentResponseCodeFailureRequiringAppLaunch, 6
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINRecurrenceFrequency(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INRecurrenceFrequency)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(Intents.INRecurrenceFrequencyUnknown, 0)
        self.assertEqual(Intents.INRecurrenceFrequencyMinute, 1)
        self.assertEqual(Intents.INRecurrenceFrequencyHourly, 2)
        self.assertEqual(Intents.INRecurrenceFrequencyDaily, 3)
        self.assertEqual(Intents.INRecurrenceFrequencyWeekly, 4)
        self.assertEqual(Intents.INRecurrenceFrequencyMonthly, 5)
        self.assertEqual(Intents.INRecurrenceFrequencyYearly, 6)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINIntentErrors(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INIntentErrorCode)

    def testConstants(self):
        self.assertEqual(Intents.INIntentErrorInteractionOperationNotSupported, 1900)
        self.assertEqual(Intents.INIntentErrorDonatingInteraction, 1901)
        self.assertEqual(Intents.INIntentErrorDeletingAllInteractions, 1902)
        self.assertEqual(Intents.INIntentErrorDeletingInteractionWithIdentifiers, 1903)
        self.assertEqual(
            Intents.INIntentErrorDeletingInteractionWithGroupIdentifier, 1904
        )
        self.assertEqual(Intents.INIntentErrorIntentSupportedByMultipleExtension, 2001)
        self.assertEqual(
            Intents.INIntentErrorRestrictedIntentsNotSupportedByExtension, 2002
        )
        self.assertEqual(Intents.INIntentErrorNoHandlerProvidedForIntent, 2003)
        self.assertEqual(Intents.INIntentErrorInvalidIntentName, 2004)
        self.assertEqual(Intents.INIntentErrorRequestTimedOut, 3001)
        self.assertEqual(Intents.INIntentErrorMissingInformation, 3002)
        self.assertEqual(Intents.INIntentErrorInvalidUserVocabularyFileLocation, 4000)

        self.assertEqual(Intents.INIntentErrorExtensionLaunchingTimeout, 5000)
        self.assertEqual(Intents.INIntentErrorExtensionBringUpFailed, 5001)

        self.assertEqual(Intents.INIntentErrorNoAppAvailable, 2005)
        self.assertEqual(Intents.INIntentErrorImageGeneric, 6000)
        self.assertEqual(Intents.INIntentErrorImageNoServiceAvailable, 6001)
        self.assertEqual(Intents.INIntentErrorImageStorageFailed, 6002)
        self.assertEqual(Intents.INIntentErrorImageLoadingFailed, 6003)
        self.assertEqual(Intents.INIntentErrorImageRetrievalFailed, 6004)
        self.assertEqual(Intents.INIntentErrorImageProxyLoop, 6005)
        self.assertEqual(Intents.INIntentErrorImageProxyInvalid, 6006)
        self.assertEqual(Intents.INIntentErrorImageProxyTimeout, 6007)
        self.assertEqual(Intents.INIntentErrorImageServiceFailure, 6008)
        self.assertEqual(Intents.INIntentErrorImageScalingFailed, 6009)
        self.assertEqual(Intents.INIntentErrorPermissionDenied, 6010)
        self.assertEqual(Intents.INIntentErrorVoiceShortcutCreationFailed, 7000)
        self.assertEqual(Intents.INIntentErrorVoiceShortcutGetFailed, 7001)
        self.assertEqual(Intents.INIntentErrorVoiceShortcutDeleteFailed, 7002)
        self.assertEqual(Intents.INIntentErrorEncodingGeneric, 8000)
        self.assertEqual(Intents.INIntentErrorEncodingFailed, 8001)
        self.assertEqual(Intents.INIntentErrorDecodingGeneric, 9000)

    @min_os_level("11.0")
    def testConstants11_0(self):
        self.assertIsInstance(Intents.INIntentErrorDomain, str)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINSearchForMessagesIntentResponse(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INSearchForMessagesIntentResponseCode)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(Intents.INSearchForMessagesIntentResponseCodeUnspecified, 0)
        self.assertEqual(Intents.INSearchForMessagesIntentResponseCodeReady, 1)
        self.assertEqual(Intents.INSearchForMessagesIntentResponseCodeInProgress, 2)
        self.assertEqual(Intents.INSearchForMessagesIntentResponseCodeSuccess, 3)
        self.assertEqual(Intents.INSearchForMessagesIntentResponseCodeFailure, 4)
        self.assertEqual(
            Intents.INSearchForMessagesIntentResponseCodeFailureRequiringAppLaunch, 5
        )
        self.assertEqual(
            Intents.INSearchForMessagesIntentResponseCodeFailureMessageServiceNotAvailable,
            6,
        )
        self.assertEqual(
            Intents.INSearchForMessagesIntentResponseCodeFailureMessageTooManyResults, 7
        )



from PyObjCTools.TestSupport import TestCase
import Intents


class TestINSendMessageRecipientResolutionResult(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INSendMessageRecipientUnsupportedReason)

    def testConstants(self):
        self.assertEqual(Intents.INSendMessageRecipientUnsupportedReasonNoAccount, 1)
        self.assertEqual(Intents.INSendMessageRecipientUnsupportedReasonOffline, 2)
        self.assertEqual(
            Intents.INSendMessageRecipientUnsupportedReasonMessagingServiceNotEnabledForRecipient,
            3,
        )

        self.assertEqual(
            Intents.INSendMessageRecipientUnsupportedReasonNoValidHandle, 4
        )
        self.assertEqual(
            Intents.INSendMessageRecipientUnsupportedReasonRequestedHandleInvalid, 5
        )
        self.assertEqual(
            Intents.INSendMessageRecipientUnsupportedReasonNoHandleForLabel, 6
        )



from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level
import Intents


class TestINStartVideoCallIntentHelper(Intents.NSObject):
    def handleStartVideoCall_completion_(self, intent, completion):
        pass

    def confirmStartVideoCall_completion_(self, intent, completion):
        pass

    def resolveContactsForStartVideoCall_withCompletion_(self, intent, completion):
        pass


class TestINStartVideoCallIntent(TestCase):
    @min_os_level("10.12")
    def testMethods(self):
        self.assertArgIsBlock(
            TestINStartVideoCallIntentHelper.handleStartVideoCall_completion_, 1, b"v@"
        )
        self.assertArgIsBlock(
            TestINStartVideoCallIntentHelper.confirmStartVideoCall_completion_, 1, b"v@"
        )
        self.assertArgIsBlock(
            TestINStartVideoCallIntentHelper.resolveContactsForStartVideoCall_withCompletion_,
            1,
            b"v@",
        )

    @min_sdk_level("10.12")
    def testProtocols(self):
        self.assertProtocolExists("INStartVideoCallIntentHandling")



from PyObjCTools.TestSupport import TestCase
import Intents


class TestINOutgoingMessageType(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INOutgoingMessageType)

    def test_constants(self):
        self.assertEqual(Intents.INOutgoingMessageTypeUnknown, 0)
        self.assertEqual(Intents.INOutgoingMessageTypeOutgoingMessageText, 1)
        self.assertEqual(Intents.INOutgoingMessageTypeOutgoingMessageAudio, 2)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINStartAudioCallIntentResponse(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INStartAudioCallIntentResponseCode)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(Intents.INStartAudioCallIntentResponseCodeUnspecified, 0)
        self.assertEqual(Intents.INStartAudioCallIntentResponseCodeReady, 1)
        self.assertEqual(Intents.INStartAudioCallIntentResponseCodeContinueInApp, 2)
        self.assertEqual(Intents.INStartAudioCallIntentResponseCodeFailure, 3)
        self.assertEqual(
            Intents.INStartAudioCallIntentResponseCodeFailureRequiringAppLaunch, 4
        )
        self.assertEqual(
            Intents.INStartAudioCallIntentResponseCodeFailureAppConfigurationRequired, 5
        )
        self.assertEqual(
            Intents.INStartAudioCallIntentResponseCodeFailureCallingServiceNotAvailable,
            6,
        )
        self.assertEqual(
            Intents.INStartAudioCallIntentResponseCodeFailureContactNotSupportedByApp, 7
        )
        self.assertEqual(
            Intents.INStartAudioCallIntentResponseCodeFailureNoValidNumber, 8
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINCallCapabilityOptions(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INCallCapabilityOptions)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(Intents.INCallCapabilityOptionAudioCall, 1 << 0)
        self.assertEqual(Intents.INCallCapabilityOptionVideoCall, 1 << 1)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINPerson(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INPersonSuggestionType)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(Intents.INPersonSuggestionTypeNone, 0)
        self.assertEqual(Intents.INPersonSuggestionTypeSocialProfile, 1)
        self.assertEqual(Intents.INPersonSuggestionTypeInstantMessageAddress, 2)

    @min_os_level("12.0")
    def test_methods(self):
        self.assertResultIsBOOL(Intents.INPerson.isContactSuggestion)



from PyObjCTools.TestSupport import TestCase
import Intents


class TestINFile(TestCase):
    def test_methods(self):
        self.assertResultIsBOOL(Intents.INFile.removedOnCompletion)
        self.assertArgIsBOOL(Intents.INFile.setRemovedOnCompletion_, 0)



from PyObjCTools.TestSupport import TestCase
import Intents


class TestINTickeetedEventCategory(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INTicketedEventCategory)

    def testConstants(self):
        self.assertEqual(Intents.INTicketedEventCategoryUnknown, 0)
        self.assertEqual(Intents.INTicketedEventCategoryMovie, 1)



from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level
import Intents


class TestINSearchForMessagesIntentHelper(Intents.NSObject):
    def handleSearchForMessages_completion_(self, intent, completion):
        pass

    def confirmSearchForMessages_completion_(self, intent, completion):
        pass

    def resolveRecipientsForSearchForMessages_withCompletion_(self, intent, completion):
        pass

    def resolveSendersForSearchForMessages_withCompletion_(self, intent, completion):
        pass

    def resolveSearchTermsForSearchForMessages_withCompletion_(
        self, intent, completion
    ):
        pass

    def resolveAttributesForSearchForMessages_withCompletion_(self, intent, completion):
        pass

    def resolveDateTimeRangeForSearchForMessages_withCompletion_(
        self, intent, completion
    ):
        pass

    def resolveIdentifiersForSearchForMessages_withCompletion_(
        self, intent, completion
    ):
        pass

    def resolveNotificationIdentifiersForSearchForMessages_withCompletion_(
        self, intent, completion
    ):
        pass

    def resolveGroupNamesForSearchForMessages_withCompletion_(self, intent, completion):
        pass

    def resolveSpeakableGroupNamesForSearchForMessages_withCompletion_(
        self, intent, completion
    ):
        pass


class TestINSearchForMessagesIntent(TestCase):
    @min_os_level("10.12")
    def testMethods(self):
        self.assertArgIsBlock(
            TestINSearchForMessagesIntentHelper.handleSearchForMessages_completion_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            TestINSearchForMessagesIntentHelper.confirmSearchForMessages_completion_,
            1,
            b"v@",
        )

        self.assertArgIsBlock(
            TestINSearchForMessagesIntentHelper.resolveRecipientsForSearchForMessages_withCompletion_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            TestINSearchForMessagesIntentHelper.resolveSendersForSearchForMessages_withCompletion_,
            1,
            b"v@",
        )
        # self.assertArgIsBlock(TestINSearchForMessagesIntentHelper.resolveSearchTermsForSearchForMessages_withCompletion_, 1, b'v@')  # noqa: B950
        self.assertArgIsBlock(
            TestINSearchForMessagesIntentHelper.resolveAttributesForSearchForMessages_withCompletion_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            TestINSearchForMessagesIntentHelper.resolveDateTimeRangeForSearchForMessages_withCompletion_,
            1,
            b"v@",
        )
        # self.assertArgIsBlock(TestINSearchForMessagesIntentHelper.resolveIdentifiersForSearchForMessages_withCompletion_, 1, b'v@')  # noqa: B950
        # self.assertArgIsBlock(TestINSearchForMessagesIntentHelper.resolveNotificationIdentifiersForSearchForMessages_withCompletion_, 1, b'v@')  # noqa: B950
        self.assertArgIsBlock(
            TestINSearchForMessagesIntentHelper.resolveGroupNamesForSearchForMessages_withCompletion_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            TestINSearchForMessagesIntentHelper.resolveSpeakableGroupNamesForSearchForMessages_withCompletion_,
            1,
            b"v@",
        )

    @min_sdk_level("10.12")
    def testProtocols(self):
        self.assertProtocolExists("INSearchForMessagesIntentHandling")



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINObjectCollection(TestCase):
    @min_os_level("11.0")
    def test_methods11_0(self):
        self.assertResultIsBOOL(Intents.INObjectCollection.usesIndexedCollation)
        self.assertArgIsBOOL(Intents.INObjectCollection.setUsesIndexedCollation_, 0)



from PyObjCTools.TestSupport import TestCase
import Intents


class TestINPaymentMethodTypes(TestCase):
    def test_constants(self):
        self.assertEqual(Intents.INPaymentMethodTypeUnknown, 0)
        self.assertEqual(Intents.INPaymentMethodTypeChecking, 1)
        self.assertEqual(Intents.INPaymentMethodTypeSavings, 2)
        self.assertEqual(Intents.INPaymentMethodTypeBrokerage, 3)
        self.assertEqual(Intents.INPaymentMethodTypeDebit, 4)
        self.assertEqual(Intents.INPaymentMethodTypeCredit, 5)
        self.assertEqual(Intents.INPaymentMethodTypePrepaid, 6)
        self.assertEqual(Intents.INPaymentMethodTypeStore, 7)
        self.assertEqual(Intents.INPaymentMethodTypeApplePay, 8)



from PyObjCTools.TestSupport import TestCase
import Intents


class TestINCallAudioRoute(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INCallAudioRoute)

    def test_constants(self):
        self.assertEqual(Intents.INCallAudioRouteUnknown, 0)
        self.assertEqual(Intents.INCallAudioRouteSpeakerphoneAudioRoute, 1)
        self.assertEqual(Intents.INCallAudioRouteBluetoothAudioRoute, 2)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINPersonSiriAdditions(TestCase):
    @min_os_level("10.14")
    def test_methods(self):
        self.assertArgIsBOOL(
            Intents.INPerson.initWithPersonHandle_nameComponents_displayName_image_contactIdentifier_customIdentifier_isMe_,
            6,
        )



from PyObjCTools.TestSupport import TestCase, min_sdk_level
import Intents


class TestINAnswerCallIntentHelper(Intents.NSObject):
    def handleAnswerCall_completion_(self, a, b):
        pass

    def confirmAnswerCall_completion_(self, a, b):
        pass


class TestINAnswerCallIntent(TestCase):
    @min_sdk_level("13.1")
    def test_protocols(self):
        self.assertProtocolExists("INAnswerCallIntentHandling")

    def test_protocol_methods(self):
        self.assertArgIsBlock(
            TestINAnswerCallIntentHelper.handleAnswerCall_completion_, 1, b"v@"
        )
        self.assertArgIsBlock(
            TestINAnswerCallIntentHelper.confirmAnswerCall_completion_, 1, b"v@"
        )



from PyObjCTools.TestSupport import TestCase
import Intents


class TestINReservationStatus(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INReservationStatus)

    def test_constants(self):
        self.assertEqual(Intents.INReservationStatusUnknown, 0)
        self.assertEqual(Intents.INReservationStatusCanceled, 1)
        self.assertEqual(Intents.INReservationStatusPending, 2)
        self.assertEqual(Intents.INReservationStatusHold, 3)
        self.assertEqual(Intents.INReservationStatusConfirmed, 4)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINBooleanResolutionResult(TestCase):
    @min_os_level("11.0")
    def test_methods11_0(self):
        self.assertArgIsBOOL(
            Intents.INBooleanResolutionResult.successWithResolvedValue_, 0
        )



from PyObjCTools.TestSupport import TestCase, min_sdk_level
import Intents


class TestINStartCallIntentHelper(Intents.NSObject):
    def handleStartCall_completion_(self, a, b):
        pass

    def confirmStartCall_completion_(self, a, b):
        pass

    def resolveCallRecordToCallBackForStartCall_withCompletion_(self, a, b):
        pass

    def resolveDestinationTypeForStartCall_withCompletion_(self, a, b):
        pass

    def resolveContactsForStartCall_withCompletion_(self, a, b):
        pass

    def resolveCallCapabilityForStartCall_withCompletion_(self, a, b):
        pass


class TestINStartCallIntent(TestCase):
    @min_sdk_level("12.0")
    def test_protocols12_0(self):
        self.assertProtocolExists("INStartCallIntentHandling")

    def test_methods(self):
        self.assertArgIsBlock(
            TestINStartCallIntentHelper.handleStartCall_completion_, 1, b"v@"
        )
        self.assertArgIsBlock(
            TestINStartCallIntentHelper.confirmStartCall_completion_, 1, b"v@"
        )
        self.assertArgIsBlock(
            TestINStartCallIntentHelper.resolveCallRecordToCallBackForStartCall_withCompletion_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            TestINStartCallIntentHelper.resolveDestinationTypeForStartCall_withCompletion_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            TestINStartCallIntentHelper.resolveContactsForStartCall_withCompletion_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            TestINStartCallIntentHelper.resolveCallCapabilityForStartCall_withCompletion_,
            1,
            b"v@",
        )



from PyObjCTools.TestSupport import TestCase
import Intents


class TestINAddMediaIntentResponse(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INAddMediaIntentResponseCode)

    def testConstants(self):
        self.assertEqual(Intents.INAddMediaIntentResponseCodeUnspecified, 0)
        self.assertEqual(Intents.INAddMediaIntentResponseCodeReady, 1)
        self.assertEqual(Intents.INAddMediaIntentResponseCodeInProgress, 2)
        self.assertEqual(Intents.INAddMediaIntentResponseCodeSuccess, 3)
        self.assertEqual(Intents.INAddMediaIntentResponseCodeHandleInApp, 4)
        self.assertEqual(Intents.INAddMediaIntentResponseCodeFailure, 5)
        self.assertEqual(
            Intents.INAddMediaIntentResponseCodeFailureRequiringAppLaunch, 6
        )



from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level
import Intents


class TestINStartAudioCallIntentHelper(Intents.NSObject):
    def handleStartAudioCall_completion_(self, intent, completion):
        pass

    def confirmStartAudioCall_completion_(self, intent, completion):
        pass

    def resolveContactsForStartAudioCall_withCompletion_(self, intent, completion):
        pass

    def resolveDestinationTypeForStartAudioCall_withCompletion_(
        self, intent, completion
    ):
        pass


class TestINStartAudioCallIntent(TestCase):
    @min_os_level("10.12")
    def testMethods(self):
        self.assertArgIsBlock(
            TestINStartAudioCallIntentHelper.handleStartAudioCall_completion_, 1, b"v@"
        )
        self.assertArgIsBlock(
            TestINStartAudioCallIntentHelper.confirmStartAudioCall_completion_, 1, b"v@"
        )
        self.assertArgIsBlock(
            TestINStartAudioCallIntentHelper.resolveContactsForStartAudioCall_withCompletion_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            TestINStartAudioCallIntentHelper.resolveDestinationTypeForStartAudioCall_withCompletion_,
            1,
            b"v@",
        )

    @min_sdk_level("10.12")
    def testProtocols(self):
        self.assertProtocolExists("INStartAudioCallIntentHandling")



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINMessageAttributeOptions(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INMessageAttributeOptions)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(Intents.INMessageAttributeOptionRead, 1 << 0)
        self.assertEqual(Intents.INMessageAttributeOptionUnread, 1 << 1)
        self.assertEqual(Intents.INMessageAttributeOptionFlagged, 1 << 2)
        self.assertEqual(Intents.INMessageAttributeOptionUnflagged, 1 << 3)
        self.assertEqual(Intents.INMessageAttributeOptionPlayed, 1 << 4)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINPersonRelationship(TestCase):
    def test_typed_enum(self):
        self.assertIsTypedEnum(Intents.INPersonRelationship, str)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertIsInstance(Intents.INPersonRelationshipFather, str)
        self.assertIsInstance(Intents.INPersonRelationshipMother, str)
        self.assertIsInstance(Intents.INPersonRelationshipParent, str)
        self.assertIsInstance(Intents.INPersonRelationshipBrother, str)
        self.assertIsInstance(Intents.INPersonRelationshipSister, str)
        self.assertIsInstance(Intents.INPersonRelationshipChild, str)
        self.assertIsInstance(Intents.INPersonRelationshipFriend, str)
        self.assertIsInstance(Intents.INPersonRelationshipSpouse, str)
        self.assertIsInstance(Intents.INPersonRelationshipPartner, str)
        self.assertIsInstance(Intents.INPersonRelationshipAssistant, str)
        self.assertIsInstance(Intents.INPersonRelationshipManager, str)

    @min_os_level("10.15")
    def testConstants10_15(self):
        self.assertIsInstance(Intents.INPersonRelationshipSon, str)
        self.assertIsInstance(Intents.INPersonRelationshipDaughter, str)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINSendMessageIntentResponse(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INSendMessageIntentResponseCode)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(Intents.INSendMessageIntentResponseCodeUnspecified, 0)
        self.assertEqual(Intents.INSendMessageIntentResponseCodeReady, 1)
        self.assertEqual(Intents.INSendMessageIntentResponseCodeInProgress, 2)
        self.assertEqual(Intents.INSendMessageIntentResponseCodeSuccess, 3)
        self.assertEqual(Intents.INSendMessageIntentResponseCodeFailure, 4)
        self.assertEqual(
            Intents.INSendMessageIntentResponseCodeFailureRequiringAppLaunch, 5
        )
        self.assertEqual(
            Intents.INSendMessageIntentResponseCodeFailureMessageServiceNotAvailable, 6
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINInteraction(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INIntentHandlingStatus)
        self.assertIsEnumType(Intents.INInteractionDirection)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(Intents.INIntentHandlingStatusUnspecified, 0)
        self.assertEqual(Intents.INIntentHandlingStatusReady, 1)
        self.assertEqual(Intents.INIntentHandlingStatusInProgress, 2)
        self.assertEqual(Intents.INIntentHandlingStatusSuccess, 3)
        self.assertEqual(Intents.INIntentHandlingStatusFailure, 4)
        self.assertEqual(Intents.INIntentHandlingStatusDeferredToApplication, 5)
        self.assertEqual(Intents.INIntentHandlingStatusUserConfirmationRequired, 6)

        self.assertEqual(Intents.INInteractionDirectionUnspecified, 0)
        self.assertEqual(Intents.INInteractionDirectionOutgoing, 1)
        self.assertEqual(Intents.INInteractionDirectionIncoming, 2)

    @min_os_level("11.0")
    def test_methods11_0(self):
        self.assertArgIsBlock(
            Intents.INInteraction.donateInteractionWithCompletion_, 0, b"v@"
        )
        self.assertArgIsBlock(
            Intents.INInteraction.deleteAllInteractionsWithCompletion_, 0, b"v@"
        )
        self.assertArgIsBlock(
            Intents.INInteraction.deleteInteractionsWithIdentifiers_completion_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            Intents.INInteraction.deleteInteractionsWithGroupIdentifier_completion_,
            1,
            b"v@",
        )



from PyObjCTools.TestSupport import TestCase
import Intents


class TestINReservationActionType(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INReservationActionType)

    def test_constants(self):
        self.assertEqual(Intents.INReservationActionTypeUnknown, 0)
        self.assertEqual(Intents.INReservationActionTypeCheckIn, 1)



from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level
import Intents


class TestINSearchCallHistoryIntentHelper(Intents.NSObject):
    def handleSearchCallHistory_completion_(self, intent, completion):
        pass

    def confirmSearchCallHistory_completion_(self, intent, completion):
        pass

    def resolveCallTypeForSearchCallHistory_withCompletion_(self, intent, completion):
        pass

    def resolveRecipientForSearchCallHistory_withCompletion_(self, intent, completion):
        pass

    def resolveCallCapabilitiesForSearchCallHistory_withCompletion_(
        self, intent, completion
    ):
        pass

    def resolveCallTypesForSearchCallHistory_withCompletion_(self, intent, completion):
        pass

    def resolveUnseenForSearchCallHistory_withCompletion_(self, intent, completion):
        pass


class TestINSearchCallHistoryIntent(TestCase):
    @min_os_level("10.12")
    def testMethods(self):
        self.assertArgIsBlock(
            TestINSearchCallHistoryIntentHelper.handleSearchCallHistory_completion_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            TestINSearchCallHistoryIntentHelper.confirmSearchCallHistory_completion_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            TestINSearchCallHistoryIntentHelper.resolveCallTypeForSearchCallHistory_withCompletion_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            TestINSearchCallHistoryIntentHelper.resolveRecipientForSearchCallHistory_withCompletion_,
            1,
            b"v@",
        )
        # Removed in Xcode 8.1
        # self.assertArgIsBlock(TestINSearchCallHistoryIntentHelper.resolveCallCapabilitiesForSearchCallHistory_withCompletion_, 1, b'v@')   # noqa: B950

    @min_os_level("10.13")
    def testMethods10_13(self):
        self.assertArgIsBlock(
            TestINSearchCallHistoryIntentHelper.resolveCallTypesForSearchCallHistory_withCompletion_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            TestINSearchCallHistoryIntentHelper.resolveUnseenForSearchCallHistory_withCompletion_,
            1,
            b"v@",
        )

    @min_sdk_level("10.12")
    def testProtocols(self):
        self.assertProtocolExists("INSearchCallHistoryIntentHandling")



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINConditionalOperator(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INConditionalOperator)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(Intents.INConditionalOperatorAll, 0)
        self.assertEqual(Intents.INConditionalOperatorAny, 1)
        self.assertEqual(Intents.INConditionalOperatorNone, 2)



from PyObjCTools.TestSupport import TestCase
import Intents


class TestINShareFocusStatusIntentResponse(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INShareFocusStatusIntentResponseCode)

    def test_constants(self):
        self.assertEqual(Intents.INShareFocusStatusIntentResponseCodeUnspecified, 0)
        self.assertEqual(Intents.INShareFocusStatusIntentResponseCodeReady, 1)
        self.assertEqual(Intents.INShareFocusStatusIntentResponseCodeInProgress, 2)
        self.assertEqual(Intents.INShareFocusStatusIntentResponseCodeSuccess, 3)
        self.assertEqual(Intents.INShareFocusStatusIntentResponseCodeFailure, 4)
        self.assertEqual(
            Intents.INShareFocusStatusIntentResponseCodeFailureRequiringAppLaunch, 5
        )



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINCallRecordType(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INCallRecordType)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(Intents.INCallRecordTypeUnknown, 0)
        self.assertEqual(Intents.INCallRecordTypeOutgoing, 1)
        self.assertEqual(Intents.INCallRecordTypeMissed, 2)
        self.assertEqual(Intents.INCallRecordTypeReceived, 3)
        self.assertEqual(Intents.INCallRecordTypeLatest, 4)
        self.assertEqual(Intents.INCallRecordTypeVoicemail, 5)
        self.assertEqual(Intents.INCallRecordTypeRinging, 6)
        self.assertEqual(Intents.INCallRecordTypeInProgress, 7)
        self.assertEqual(Intents.INCallRecordTypeOnHold, 8)

        self.assertEqual(Intents.INCallRecordTypeLatest, 4)
        self.assertEqual(Intents.INCallRecordTypeVoicemail, 5)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINCallRecordTypeOptions(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INCallRecordTypeOptions)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(Intents.INCallRecordTypeOptionOutgoing, 1 << 0)
        self.assertEqual(Intents.INCallRecordTypeOptionMissed, 1 << 1)
        self.assertEqual(Intents.INCallRecordTypeOptionReceived, 1 << 2)
        self.assertEqual(Intents.INCallRecordTypeOptionLatest, 1 << 3)
        self.assertEqual(Intents.INCallRecordTypeOptionVoicemail, 1 << 4)
        self.assertEqual(Intents.INCallRecordTypeOptionRinging, 1 << 5)
        self.assertEqual(Intents.INCallRecordTypeOptionInProgress, 1 << 6)
        self.assertEqual(Intents.INCallRecordTypeOptionOnHold, 1 << 7)



from PyObjCTools.TestSupport import (
    TestCase,
    min_os_level,
    os_release,
    os_level_key,
    expectedFailureIf,
)
import Intents


class TestINIntentIdentifiers(TestCase):
    @min_os_level("10.12")
    @expectedFailureIf(
        os_level_key(os_release()) < os_level_key("10.14")
    )  # Documented to be available for 10.12, but not available
    def testConstants(self):
        self.assertIsInstance(Intents.INStartAudioCallIntentIdentifier, str)
        self.assertIsInstance(Intents.INStartVideoCallIntentIdentifier, str)
        self.assertIsInstance(Intents.INSearchCallHistoryIntentIdentifier, str)
        self.assertIsInstance(Intents.INSendMessageIntentIdentifier, str)
        self.assertIsInstance(Intents.INSearchForMessagesIntentIdentifier, str)
        self.assertIsInstance(Intents.INSetMessageAttributeIntentIdentifier, str)

    @min_os_level("13.1")
    def test_constants13_1(self):
        self.assertIsInstance(Intents.INAnswerCallIntentIdentifier, str)
        self.assertIsInstance(Intents.INHangUpCallIntentIdentifier, str)



from PyObjCTools.TestSupport import TestCase, min_sdk_level
import Intents


class TestINHangUpCallIntentHelper(Intents.NSObject):
    def handleHangUpCall_completion_(self, a, b):
        pass

    def confirmHangUpCall_completion_(self, a, b):
        pass


class TestINHangUpCallIntent(TestCase):
    @min_sdk_level("13.1")
    def test_protocols(self):
        self.assertProtocolExists("INHangUpCallIntentHandling")

    def test_protocol_methods(self):
        self.assertArgIsBlock(
            TestINHangUpCallIntentHelper.handleHangUpCall_completion_, 1, b"v@"
        )
        self.assertArgIsBlock(
            TestINHangUpCallIntentHelper.confirmHangUpCall_completion_, 1, b"v@"
        )



from PyObjCTools.TestSupport import TestCase
import Intents


class TestINCallRecordResolutionResult(TestCase):
    def test_constants(self):
        self.assertEqual(
            Intents.INStartCallCallRecordToCallBackUnsupportedReasonNoMatchingCall, 1
        )



from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level
import Intents


class TestINSendMessageIntentHelper(Intents.NSObject):
    def handleSendMessage_completion_(self, intent, completion):
        pass

    def confirmSendMessage_completion_(self, intent, completion):
        pass

    def resolveRecipientsForSendMessage_withCompletion_(self, intent, completion):
        pass

    def resolveContentForSendMessage_withCompletion_(self, intent, completion):
        pass

    def resolveGroupNameForSendMessage_withCompletion_(self, intent, completion):
        pass

    def resolveServiceNameForSendMessage_withCompletion_(self, intent, completion):
        pass

    def resolveSenderForSendMessage_withCompletion_(self, intent, completion):
        pass

    def resolveSpeakableGroupNameForSendMessage_withCompletion_(
        self, intent, completion
    ):
        pass

    def resolveRecipientsForSendMessage_completion_(self, intent, completion):
        pass


class TestINSendMessageIntent(TestCase):
    @min_os_level("10.12")
    def testMethods(self):
        self.assertArgIsBlock(
            TestINSendMessageIntentHelper.handleSendMessage_completion_, 1, b"v@"
        )
        self.assertArgIsBlock(
            TestINSendMessageIntentHelper.confirmSendMessage_completion_, 1, b"v@"
        )
        self.assertArgIsBlock(
            TestINSendMessageIntentHelper.resolveRecipientsForSendMessage_withCompletion_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            TestINSendMessageIntentHelper.resolveContentForSendMessage_withCompletion_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            TestINSendMessageIntentHelper.resolveContentForSendMessage_withCompletion_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            TestINSendMessageIntentHelper.resolveGroupNameForSendMessage_withCompletion_,
            1,
            b"v@",
        )
        # self.assertArgIsBlock(TestINSendMessageIntentHelper.resolveServiceNameForSendMessage_withCompletion_, 1, b'v@')
        # self.assertArgIsBlock(TestINSendMessageIntentHelper.resolveSenderForSendMessage_withCompletion_, 1, b'v@')
        self.assertArgIsBlock(
            TestINSendMessageIntentHelper.resolveSpeakableGroupNameForSendMessage_withCompletion_,
            1,
            b"v@",
        )

    @min_os_level("10.13")
    def testMethods10_13(self):
        self.assertArgIsBlock(
            TestINSendMessageIntentHelper.resolveRecipientsForSendMessage_completion_,
            1,
            b"v@",
        )

    @min_sdk_level("10.12")
    def testProtocols(self):
        self.assertProtocolExists("INSendMessageIntentHandling")



from PyObjCTools.TestSupport import TestCase
import Intents


class TestINGetReservationDetailsIntentResponse(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INGetReservationDetailsIntentResponseCode)

    def testConstants(self):
        self.assertEqual(
            Intents.INGetReservationDetailsIntentResponseCodeUnspecified, 0
        )
        self.assertEqual(Intents.INGetReservationDetailsIntentResponseCodeReady, 1)
        self.assertEqual(Intents.INGetReservationDetailsIntentResponseCodeInProgress, 2)
        self.assertEqual(Intents.INGetReservationDetailsIntentResponseCodeSuccess, 3)
        self.assertEqual(Intents.INGetReservationDetailsIntentResponseCodeFailure, 4)
        self.assertEqual(
            Intents.INGetReservationDetailsIntentResponseCodeFailureRequiringAppLaunch,
            5,
        )



from PyObjCTools.TestSupport import TestCase
import Intents


class TestINMessage(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INMessageType)

    def testConstants(self):
        self.assertEqual(Intents.INMessageTypeUnspecified, 0)
        self.assertEqual(Intents.INMessageTypeText, 1)
        self.assertEqual(Intents.INMessageTypeAudio, 2)
        self.assertEqual(Intents.INMessageTypeDigitalTouch, 3)
        self.assertEqual(Intents.INMessageTypeHandwriting, 4)
        self.assertEqual(Intents.INMessageTypeSticker, 5)
        self.assertEqual(Intents.INMessageTypeTapbackLiked, 6)
        self.assertEqual(Intents.INMessageTypeTapbackDisliked, 7)
        self.assertEqual(Intents.INMessageTypeTapbackEmphasized, 8)
        self.assertEqual(Intents.INMessageTypeTapbackLoved, 9)
        self.assertEqual(Intents.INMessageTypeTapbackQuestioned, 10)
        self.assertEqual(Intents.INMessageTypeTapbackLaughed, 11)
        self.assertEqual(Intents.INMessageTypeMediaCalendar, 12)
        self.assertEqual(Intents.INMessageTypeMediaLocation, 13)
        self.assertEqual(Intents.INMessageTypeMediaAddressCard, 14)
        self.assertEqual(Intents.INMessageTypeMediaImage, 15)
        self.assertEqual(Intents.INMessageTypeMediaVideo, 16)
        self.assertEqual(Intents.INMessageTypeMediaPass, 17)
        self.assertEqual(Intents.INMessageTypeMediaAudio, 18)

        self.assertEqual(Intents.INMessageTypePaymentSent, 19)
        self.assertEqual(Intents.INMessageTypePaymentRequest, 20)
        self.assertEqual(Intents.INMessageTypePaymentNote, 21)
        self.assertEqual(Intents.INMessageTypeAnimoji, 22)
        self.assertEqual(Intents.INMessageTypeActivitySnippet, 23)
        self.assertEqual(Intents.INMessageTypeFile, 24)
        self.assertEqual(Intents.INMessageTypeLink, 25)



from PyObjCTools.TestSupport import TestCase, min_sdk_level
import Intents


class TestINShareFocusStatusIntentHelper(Intents.NSObject):
    def handleShareFocusStatus_completion_(self, a, b):
        pass

    def confirmShareFocusStatus_completion_(self, a, b):
        pass


class TestINShareFocusStatusIntent(TestCase):
    @min_sdk_level("12.0")
    def test_protocols(self):
        self.assertProtocolExists("INShareFocusStatusIntentHandling")

    def test_methods(self):
        self.assertArgIsBlock(
            TestINShareFocusStatusIntentHelper.handleShareFocusStatus_completion_,
            1,
            b"v@",
        )
        self.assertArgIsBlock(
            TestINShareFocusStatusIntentHelper.confirmShareFocusStatus_completion_,
            1,
            b"v@",
        )



"""
Python mapping for the Intents framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Foundation
import objc
from Intents import _metadata
from Intents import _Intents

sys.modules["Intents"] = mod = objc.ObjCLazyModule(
    "Intents",
    "com.apple.Intents",
    objc.pathForFramework("/System/Library/Frameworks/Intents.framework"),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (_Intents, Foundation),
)


del sys.modules["Intents._metadata"]



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINCallDestinationType(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INCallDestinationType)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(Intents.INCallDestinationTypeUnknown, 0)
        self.assertEqual(Intents.INCallDestinationTypeNormalDestination, 1)
        self.assertEqual(Intents.INCallDestinationTypeEmergencyDestination, 2)
        self.assertEqual(Intents.INCallDestinationTypeVoicemailDestination, 3)
        self.assertEqual(Intents.INCallDestinationTypeRedialDestination, 4)

        self.assertEqual(Intents.INCallDestinationTypeNormal, 1)
        self.assertEqual(Intents.INCallDestinationTypeEmergency, 2)
        self.assertEqual(Intents.INCallDestinationTypeVoicemail, 3)
        self.assertEqual(Intents.INCallDestinationTypeRedial, 4)

        self.assertEqual(Intents.INCallDestinationTypeUnknown, 0)
        self.assertEqual(Intents.INCallDestinationTypeNormal, 1)
        self.assertEqual(Intents.INCallDestinationTypeEmergency, 2)
        self.assertEqual(Intents.INCallDestinationTypeVoicemail, 3)
        self.assertEqual(Intents.INCallDestinationTypeRedial, 4)
        self.assertEqual(Intents.INCallDestinationTypeCallBack, 5)
        self.assertEqual(Intents.INCallDestinationTypeNormalDestination, 1)
        self.assertEqual(Intents.INCallDestinationTypeEmergencyDestination, 2)
        self.assertEqual(Intents.INCallDestinationTypeVoicemailDestination, 3)
        self.assertEqual(Intents.INCallDestinationTypeRedialDestination, 4)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINSearchCallHistoryIntentResponse(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INSearchCallHistoryIntentResponseCode)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(Intents.INSearchCallHistoryIntentResponseCodeUnspecified, 0)
        self.assertEqual(Intents.INSearchCallHistoryIntentResponseCodeReady, 1)
        self.assertEqual(Intents.INSearchCallHistoryIntentResponseCodeContinueInApp, 2)
        self.assertEqual(Intents.INSearchCallHistoryIntentResponseCodeFailure, 3)
        self.assertEqual(
            Intents.INSearchCallHistoryIntentResponseCodeFailureRequiringAppLaunch, 4
        )
        self.assertEqual(
            Intents.INSearchCallHistoryIntentResponseCodeFailureAppConfigurationRequired,
            5,
        )
        self.assertEqual(Intents.INSearchCallHistoryIntentResponseCodeInProgress, 6)
        self.assertEqual(Intents.INSearchCallHistoryIntentResponseCodeSuccess, 7)



from PyObjCTools.TestSupport import TestCase, min_os_level
import Intents


class TestINCallCapability(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(Intents.INCallCapability)

    @min_os_level("10.12")
    def testConstants(self):
        self.assertEqual(Intents.INCallCapabilityUnknown, 0)
        self.assertEqual(Intents.INCallCapabilityAudioCall, 1)
        self.assertEqual(Intents.INCallCapabilityVideoCall, 2)
